@@ -13,35 +13,34 @@ typedef Eo Ecore_Audio_Out;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Ecore Audio output object.
  *
  * @ingroup Ecore_Audio_Out
  */
 #define ECORE_AUDIO_OUT_CLASS ecore_audio_out_class_get()
 
-EWAPI const Eo_Class *ecore_audio_out_class_get(void);
+EWAPI const Efl_Class *ecore_audio_out_class_get(void);
 
 /**
- * @brief Attach an input to an output
+ * @brief Attaches an input to an output
  *
+ * @param[in] obj The object.
  * @param[in] input The input to attach to the output
  *
- * @return true if the input was attached, false otherwise
- *
- * @since 1.8
+ * @return @c true if the input was attached, @c false otherwise
  *
  * @ingroup Ecore_Audio_Out
  */
 EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Eo *obj, Ecore_Audio_In *input);
 
 /**
- * @brief Detach an input from an output
+ * @brief Detaches an input from an output
  *
+ * @param[in] obj The object.
  * @param[in] input The input to detach to the output
  *
- * @return true if the input was detached, false otherwise
- *
- * @since 1.8
+ * @return @c true if the input was detached, @c false otherwise
  *
  * @ingroup Ecore_Audio_Out
  */
@@ -50,13 +49,13 @@ EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Eo *obj, Ecore_Audio_In *input)
 /**
  * @brief Returns the list of all attached inputs
  *
- * @return A list of the inputs that are attached to the output
+ * @param[in] obj The object.
  *
- * @since 1.8
+ * @return A list of the inputs that are attached to the output
  *
  * @ingroup Ecore_Audio_Out
  */
 EOAPI Eina_List *ecore_audio_obj_out_inputs_get(Eo *obj);
-
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
