@@ -11,11 +11,10 @@ typedef Eo Efl_Net_Dialer_Websocket;
 #ifndef _EFL_NET_DIALER_WEBSOCKET_EO_TYPES
 #define _EFL_NET_DIALER_WEBSOCKET_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** How to map WebSocket to EFL I/O Interfaces.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef enum
 {
@@ -34,7 +33,9 @@ typedef enum
                                                 * @ref efl_net_dialer_websocket_text_send
                                                 */
 } Efl_Net_Dialer_Websocket_Streaming_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Registered reasons for the CLOSE (opcode=0x8).
  *
@@ -43,9 +44,7 @@ typedef enum
  *
  * See https://tools.ietf.org/html/rfc6455#section-7.4.1
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef enum
 {
@@ -152,21 +151,23 @@ typedef enum
                                                             * use range
                                                             * 4000-4999 */
 } Efl_Net_Dialer_Websocket_Close_Reason;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Close reason event payload.
  *
- * @since 1.19
- *
- * @ingroup Efl_Net_Dialer_Websocket
+ * @ingroup Efl_Net
  */
 typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
 {
   Efl_Net_Dialer_Websocket_Close_Reason reason; /**< Closing reason */
   const char *message; /**< Textual closing reason message */
 } Efl_Net_Dialer_Websocket_Closed_Reason;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief WebSocket Dialer (Client).
  *
@@ -174,14 +175,15 @@ typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
  * message-based protocol over HTTP, this allows it to leverage on
  * authentication, cookies, proxies and SSL/TLS.
  *
- * It's worth to note that although it uses the HTTP dialer, it's not a
- * subclass and thus not all HTTP features are exposed as the WebSocket has
- * strict requirements that must be respected.
+ * Although it uses the HTTP dialer, it's not a subclass and thus not all HTTP
+ * features are exposed as the WebSocket has strict requirements that must be
+ * respected.
  *
  * If the proxy is NULL (default), then the system proxy will be used. On UNIX
  * that's the environment variable @c http_proxy (or '$all_proxy') is used if
- * the given address doesn't match @c no_proxy patterns. To disable proxy use
- * an empty string. If provided proxy must be one of the protocols:
+ * the given address doesn't match @c no_proxy patterns. To disable the proxy
+ * use an empty string. If provided, the proxy must be one of the following
+ * protocols:
  *
  * - http://username:password\@proxyserver:port -
  * http://username\@proxyserver:port - http://proxyserver:port -
@@ -192,8 +194,6 @@ typedef struct _Efl_Net_Dialer_Websocket_Closed_Reason
  * socks4a://proxyserver:port (SOCKSv4 and let socks server to resolve domain)
  * - socks4://proxyserver:port (SOCKSv4)
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 #define EFL_NET_DIALER_WEBSOCKET_CLASS efl_net_dialer_websocket_class_get()
@@ -203,12 +203,11 @@ EWAPI const Efl_Class *efl_net_dialer_websocket_class_get(void);
 /**
  * @brief Sends a PING (opcode=0x9) to the server.
  *
- * The server should reply with a PONG, that will be emitted as "pong" event.
+ * The server should reply with a PONG, which will be emitted as "pong" event.
  *
+ * @param[in] obj The object.
  * @param[in] reason Reason
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_ping(Eo *obj, const char *reason);
@@ -216,16 +215,14 @@ EOAPI void efl_net_dialer_websocket_ping(Eo *obj, const char *reason);
 /**
  * @brief Sends an UTF-8 TEXT (opcode=0x1) to the server.
  *
- * The text goes in a message will be delivered as a single entity to the
- * remote peer.
+ * The message text will be delivered as a single entity to the remote peer.
  *
- * The text is copied into a local buffer, no references are kept after this
+ * The text is copied into a local buffer. No references are kept after this
  * method returns.
  *
+ * @param[in] obj The object.
  * @param[in] text Text to send
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_text_send(Eo *obj, const char *text);
@@ -233,16 +230,15 @@ EOAPI void efl_net_dialer_websocket_text_send(Eo *obj, const char *text);
 /**
  * @brief Sends a binary blob (opcode=0x2) to the server.
  *
- * The slice describing the blob goes in a message will be delivered as a
+ * The slice describing the blob goes in a message which will be delivered as a
  * single entity to the remote peer.
  *
  * The memory is copied into a local buffer, no references are kept after this
  * method returns.
  *
+ * @param[in] obj The object.
  * @param[in] blob Binary blob to send
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_binary_send(Eo *obj, const Eina_Slice blob);
@@ -251,22 +247,21 @@ EOAPI void efl_net_dialer_websocket_binary_send(Eo *obj, const Eina_Slice blob);
  * @brief Requests (opcode=0x8) the server to terminate the connection.
  *
  * Unlike @ref efl_io_closer_close, this won't abruptly close the connection,
- * rather will queue a message requesting the server to gracefully close it.
+ * rather it'll queue a message requesting the server to gracefully close it.
  *
  * After this method is called you should consider the object in "closing"
- * state, no more messages can be sent (@Efl.Net.Dialer.Websocket.text_send,
+ * state. No more messages can be sent (@Efl.Net.Dialer_Websocket.text_send,
  * @ref efl_net_dialer_websocket_binary_send and
  * @ref efl_net_dialer_websocket_ping will fail).
  *
  * The object will be automatically closed with @ref efl_io_closer_close once
- * the serve replies with his own close message, that will be reported as
+ * the server replies with his own close message, which will be reported as
  * "closed,reason".
  *
+ * @param[in] obj The object.
  * @param[in] reason Reason for closing
  * @param[in] message Additional closing message
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_close_request(Eo *obj, Efl_Net_Dialer_Websocket_Close_Reason reason, const char *message);
@@ -276,10 +271,9 @@ EOAPI void efl_net_dialer_websocket_close_request(Eo *obj, Efl_Net_Dialer_Websoc
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] protocol WebSocket protocol
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_request_protocol_add(Eo *obj, const char *protocol);
@@ -287,17 +281,15 @@ EOAPI void efl_net_dialer_websocket_request_protocol_add(Eo *obj, const char *pr
 /**
  * @brief Returns an iterator to the requested WebSocket protocols
  *
- * @return Iterator to protocols
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Iterator to protocols
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI Eina_Iterator *efl_net_dialer_websocket_request_protocols_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /** Clears all request protocols
- *
- * @since 1.19
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -307,9 +299,9 @@ EOAPI void efl_net_dialer_websocket_request_protocols_clear(Eo *obj);
  * @brief Returns an iterator to the server-replied (response) WebSocket
  * protocols it supports
  *
- * @return Iterator to server protocols
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Iterator to server protocols
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -335,12 +327,11 @@ EOAPI Eina_Iterator *efl_net_dialer_websocket_response_protocols_get(Eo *obj) EI
  * differs from SOCK_SEQPACKET + read(2)).
  *
  * By default, streaming is disabled
- * (@Efl.Net.Dialer.Websocket.Streaming_Mode.disabled).
+ * (@Efl.Net.Dialer_Websocket_Streaming_Mode.disabled).
  *
+ * @param[in] obj The object.
  * @param[in] streaming_mode Streaming mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_streaming_mode_set(Eo *obj, Efl_Net_Dialer_Websocket_Streaming_Mode streaming_mode);
@@ -365,12 +356,12 @@ EOAPI void efl_net_dialer_websocket_streaming_mode_set(Eo *obj, Efl_Net_Dialer_W
  * differs from SOCK_SEQPACKET + read(2)).
  *
  * By default, streaming is disabled
- * (@Efl.Net.Dialer.Websocket.Streaming_Mode.disabled).
+ * (@Efl.Net.Dialer_Websocket_Streaming_Mode.disabled).
+ *
+ * @param[in] obj The object.
  *
  * @return Streaming mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI Efl_Net_Dialer_Websocket_Streaming_Mode efl_net_dialer_websocket_streaming_mode_get(const Eo *obj);
@@ -380,10 +371,9 @@ EOAPI Efl_Net_Dialer_Websocket_Streaming_Mode efl_net_dialer_websocket_streaming
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] user_agent User-agent
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_user_agent_set(Eo *obj, const char *user_agent);
@@ -393,9 +383,9 @@ EOAPI void efl_net_dialer_websocket_user_agent_set(Eo *obj, const char *user_age
  *
  * This should be set before dialing.
  *
- * @return User-agent
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return User-agent
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -406,14 +396,13 @@ EOAPI const char *efl_net_dialer_websocket_user_agent_get(const Eo *obj);
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] username HTTP authentication username
  * @param[in] password HTTP authentication password
- * @param[in] method Authentication method to use, defaults to
+ * @param[in] method The authentication method to use. Defaults to
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[in] restricted Restrict method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_authentication_set(Eo *obj, const char *username, const char *password, Efl_Net_Http_Authentication_Method method, Eina_Bool restricted);
@@ -423,14 +412,13 @@ EOAPI void efl_net_dialer_websocket_authentication_set(Eo *obj, const char *user
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[out] username HTTP authentication username
  * @param[out] password HTTP authentication password
- * @param[out] method Authentication method to use, defaults to
+ * @param[out] method The authentication method to use. Defaults to
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[out] restricted Restrict method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_authentication_get(const Eo *obj, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted);
@@ -440,11 +428,10 @@ EOAPI void efl_net_dialer_websocket_authentication_get(const Eo *obj, const char
  *
  * This should be set before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] allow_redirects @c true when following redirects, @c false
  * otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_allow_redirects_set(Eo *obj, Eina_Bool allow_redirects);
@@ -454,9 +441,9 @@ EOAPI void efl_net_dialer_websocket_allow_redirects_set(Eo *obj, Eina_Bool allow
  *
  * This should be set before dialing.
  *
- * @return @c true when following redirects, @c false otherwise
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return @c true when following redirects, @c false otherwise
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -475,11 +462,10 @@ EOAPI Eina_Bool efl_net_dialer_websocket_allow_redirects_get(const Eo *obj);
  *
  * This should be called before dialing.
  *
+ * @param[in] obj The object.
  * @param[in] key HTTP request header key
  * @param[in] value HTTP request header value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_request_header_add(Eo *obj, const char *key, const char *value);
@@ -490,8 +476,7 @@ EOAPI void efl_net_dialer_websocket_request_header_add(Eo *obj, const char *key,
  * See @ref efl_net_dialer_websocket_request_header_add
  *
  * This should be called before dialing.
- *
- * @since 1.19
+ * @param[in] obj The object.
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -500,9 +485,9 @@ EOAPI void efl_net_dialer_websocket_request_headers_clear(Eo *obj);
 /**
  * @brief Returns an iterator to the key-value pairs for request headers
  *
- * @return Iterator to key value pairs
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Iterator to key value pairs
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -511,28 +496,27 @@ EOAPI Eina_Iterator *efl_net_dialer_websocket_request_headers_get(Eo *obj) EINA_
 /**
  * @brief This property sets the filename where to read and write cookies.
  *
- * By setting a file to load and persist cookies to, the internal cookie system
- * will be activated, automatically handling HTTP headers such as 'Set-cookie:'
- * and sending the appropriate cookies for a server.
+ * By setting a file to load and store cookies, the internal cookie system will
+ * be activated, automatically handling HTTP headers such as 'Set-cookie:' and
+ * sending the appropriate cookies for a server.
  *
  * If a new, empty session is to be used, start with an empty or non-existent
- * file such as created with mkstemp() or tmpfile(). An alternative is to use
- * an empty string ("") to keep it in memory.
+ * file such as one created with mkstemp() or tmpfile(). Alternatively use an
+ * empty string ("") to keep it in memory.
  *
- * If it is desired to start from a pre-existent cookie jar but do not want to
- * modify that, first copy that file and then pass the new, temporary file.
+ * If you want to start from a pre-existent cookie jar but do not want to
+ * modify it, first copy that file and then pass the new, temporary file.
  *
- * Likewise, if it's desired to fill some cookies to the system, create a
- * cookie jar and pass its path to this property.
+ * Likewise, if you want to store some cookies in the system, create a cookie
+ * jar and pass its path to this property.
  *
  * @note that whenever this property is set, even if to the same value, it will
  * flush all cookies to the previously set file, then erase all known cookies,
  * then use the new file (if any).
  *
+ * @param[in] obj The object.
  * @param[in] path Path to cookie jar
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 EOAPI void efl_net_dialer_websocket_cookie_jar_set(Eo *obj, const char *path);
@@ -540,27 +524,27 @@ EOAPI void efl_net_dialer_websocket_cookie_jar_set(Eo *obj, const char *path);
 /**
  * @brief This property sets the filename where to read and write cookies.
  *
- * By setting a file to load and persist cookies to, the internal cookie system
- * will be activated, automatically handling HTTP headers such as 'Set-cookie:'
- * and sending the appropriate cookies for a server.
+ * By setting a file to load and store cookies, the internal cookie system will
+ * be activated, automatically handling HTTP headers such as 'Set-cookie:' and
+ * sending the appropriate cookies for a server.
  *
  * If a new, empty session is to be used, start with an empty or non-existent
- * file such as created with mkstemp() or tmpfile(). An alternative is to use
- * an empty string ("") to keep it in memory.
+ * file such as one created with mkstemp() or tmpfile(). Alternatively use an
+ * empty string ("") to keep it in memory.
  *
- * If it is desired to start from a pre-existent cookie jar but do not want to
- * modify that, first copy that file and then pass the new, temporary file.
+ * If you want to start from a pre-existent cookie jar but do not want to
+ * modify it, first copy that file and then pass the new, temporary file.
  *
- * Likewise, if it's desired to fill some cookies to the system, create a
- * cookie jar and pass its path to this property.
+ * Likewise, if you want to store some cookies in the system, create a cookie
+ * jar and pass its path to this property.
  *
  * @note that whenever this property is set, even if to the same value, it will
  * flush all cookies to the previously set file, then erase all known cookies,
  * then use the new file (if any).
  *
- * @return Path to cookie jar
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return Path to cookie jar
  *
  * @ingroup Efl_Net_Dialer_Websocket
  */
@@ -571,8 +555,6 @@ EWAPI extern const Efl_Event_Description _EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE
 /** Received a text string message (opcode=0x1)
  * @return const char *
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 #define EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE_TEXT (&(_EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE_TEXT))
@@ -582,8 +564,6 @@ EWAPI extern const Efl_Event_Description _EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE
 /** Received a binary message (opcode=0x2)
  * @return const Eina_Slice *
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 #define EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE_BINARY (&(_EFL_NET_DIALER_WEBSOCKET_EVENT_MESSAGE_BINARY))
@@ -593,8 +573,6 @@ EWAPI extern const Efl_Event_Description _EFL_NET_DIALER_WEBSOCKET_EVENT_PONG;
 /** Received a pong (opcode=0xA) with optional message/reason
  * @return const char *
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 #define EFL_NET_DIALER_WEBSOCKET_EVENT_PONG (&(_EFL_NET_DIALER_WEBSOCKET_EVENT_PONG))
@@ -608,10 +586,9 @@ EWAPI extern const Efl_Event_Description _EFL_NET_DIALER_WEBSOCKET_EVENT_CLOSED_
  * called.
  * @return Efl_Net_Dialer_Websocket_Closed_Reason
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Websocket
  */
 #define EFL_NET_DIALER_WEBSOCKET_EVENT_CLOSED_REASON (&(_EFL_NET_DIALER_WEBSOCKET_EVENT_CLOSED_REASON))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
