@@ -11,6 +11,7 @@ typedef Eo Eio_Sentry;
 #ifndef _EIO_SENTRY_EO_TYPES
 #define _EIO_SENTRY_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Wraps the data about a monitor event on a file.
  *
  * @ingroup Eio_Sentry
@@ -20,9 +21,11 @@ typedef struct _Eio_Sentry_Event
   const char *trigger; /**< The cause of the event. */
   const char *source; /**< The original monitored path. */
 } Eio_Sentry_Event;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Monitors files and directories for changes.
  *
  * @ingroup Eio_Sentry
@@ -53,7 +56,7 @@ EOAPI Eina_Bool eio_sentry_add(Eo *obj, const char *path);
  */
 EOAPI void eio_sentry_remove(Eo *obj, const char *path);
 
-#ifdef EIO_SENTRY_BETA
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Return if the sentry is using the fallback monitoring method
  *
@@ -67,7 +70,7 @@ EOAPI void eio_sentry_remove(Eo *obj, const char *path);
  * @ingroup Eio_Sentry
  */
 EOAPI Eina_Bool eio_sentry_fallback_check(const Eo *obj, const char *path);
-#endif
+#endif /* EFL_BETA_API_SUPPORT */
 
 EWAPI extern const Efl_Event_Description _EIO_SENTRY_EVENT_FILE_CREATED;
 
@@ -167,5 +170,6 @@ EWAPI extern const Efl_Event_Description _EIO_SENTRY_EVENT_ERROR;
  * @ingroup Eio_Sentry
  */
 #define EIO_SENTRY_EVENT_ERROR (&(_EIO_SENTRY_EVENT_ERROR))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
