@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Box_Stack;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A custom layout engine for @ref Efl_Ui_Box that stacks items.
  *
@@ -23,5 +24,6 @@ typedef Eo Efl_Ui_Box_Stack;
 #define EFL_UI_BOX_STACK_CLASS efl_ui_box_stack_class_get()
 
 EWAPI const Efl_Class *efl_ui_box_stack_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
