@@ -11,10 +11,11 @@ typedef Eo Efl_Ui_Calendar;
 #ifndef _EFL_UI_CALENDAR_EO_TYPES
 #define _EFL_UI_CALENDAR_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A weekday
  *
- * See also @ref Efl.Ui.Calendar.first_day_of_week.set.
+ * See also @ref efl_ui_calendar_first_day_of_week_set.
  *
  * @ingroup Efl_Ui
  */
@@ -22,7 +23,7 @@ typedef enum
 {
   EFL_UI_CALENDAR_WEEKDAY_SUNDAY = 0, /**< Sunday weekday */
   EFL_UI_CALENDAR_WEEKDAY_MONDAY, /**< Monday weekday */
-  EFL_UI_CALENDAR_WEEKDAY_TUESDAY, /**< Tusday weekday */
+  EFL_UI_CALENDAR_WEEKDAY_TUESDAY, /**< Tuesday weekday */
   EFL_UI_CALENDAR_WEEKDAY_WEDNESDAY, /**< Wednesday weekday */
   EFL_UI_CALENDAR_WEEKDAY_THURSDAY, /**< Thursday weekday */
   EFL_UI_CALENDAR_WEEKDAY_FRIDAY, /**< Friday weekday */
@@ -30,16 +31,9 @@ typedef enum
   EFL_UI_CALENDAR_WEEKDAY_LAST /**< Sentinel value to indicate last enum field
                                 * during iteration */
 } Efl_Ui_Calendar_Weekday;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
 
-
-
-
-
-
-
-
-
 #endif
