@@ -11,6 +11,7 @@ typedef Eo Efl_Ui_Clock;
 #ifndef _EFL_UI_CLOCK_EO_TYPES
 #define _EFL_UI_CLOCK_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Identifies a clock field, The widget supports 6 fields : Year, month, Date,
  * Hour, Minute, AM/PM
  *
@@ -27,24 +28,9 @@ typedef enum
   EFL_UI_CLOCK_TYPE_DAY = 6, /**< Indicated Day field. */
   EFL_UI_CLOCK_TYPE_AMPM = 7 /**< Indicates AM/PM field . */
 } Efl_Ui_Clock_Type;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #endif
