@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Focus_Util;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** EFL UI Focus Util class
  *
  * @ingroup Efl_Ui_Focus_Util
@@ -28,7 +29,7 @@ EWAPI const Efl_Class *efl_ui_focus_util_class_get(void);
  *
  * @ingroup Efl_Ui_Focus_Util
  */
-EOAPI void efl_ui_focus_util_focus(const Eo *obj, Efl_Ui_Focus_Object *focus_elem);
+EOAPI void efl_ui_focus_util_focus(Efl_Ui_Focus_Object *focus_elem);
 
 /**
  * @brief Get the highest manager in the redirect property
@@ -37,8 +38,9 @@ EOAPI void efl_ui_focus_util_focus(const Eo *obj, Efl_Ui_Focus_Object *focus_ele
  *
  * @ingroup Efl_Ui_Focus_Util
  */
-EOAPI Efl_Ui_Focus_Manager *efl_ui_focus_util_active_manager(const Eo *obj, Efl_Ui_Focus_Manager *manager);
+EOAPI Efl_Ui_Focus_Manager *efl_ui_focus_util_active_manager(Efl_Ui_Focus_Manager *manager);
 
-EOAPI Efl_Ui_Focus_Direction efl_ui_focus_util_direction_complement(const Eo *obj, Efl_Ui_Focus_Direction dir);
+EOAPI Efl_Ui_Focus_Direction efl_ui_focus_util_direction_complement(Efl_Ui_Focus_Direction dir);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
