@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Layout_Part_Bg;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elementary layout internal part background class
  *
  * @ingroup Efl_Ui_Layout_Part_Bg
@@ -20,5 +21,6 @@ typedef Eo Efl_Ui_Layout_Part_Bg;
 #define EFL_UI_LAYOUT_PART_BG_CLASS efl_ui_layout_part_bg_class_get()
 
 EWAPI const Efl_Class *efl_ui_layout_part_bg_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
