@@ -11,12 +11,15 @@ typedef Eo Efl_Ui_Tab_Page;
 #ifndef _EFL_UI_TAB_PAGE_EO_TYPES
 #define _EFL_UI_TAB_PAGE_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 typedef enum
 {
   EFL_UI_TAB_PAGE_TAB_CHANGED_LABEL = 0, /**< Label changed */
   EFL_UI_TAB_PAGE_TAB_CHANGED_ICON /**< Icon changed */
 } Efl_Ui_Tab_Page_Tab_Changed;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Information of changed event
  *
  * @ingroup Efl_Ui
@@ -25,9 +28,11 @@ typedef struct _Efl_Ui_Tab_Page_Tab_Changed_Event
 {
   Efl_Ui_Tab_Page_Tab_Changed changed_info;
 } Efl_Ui_Tab_Page_Tab_Changed_Event;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Tab Page class
  *
  * @ingroup Efl_Ui_Tab_Page
@@ -44,5 +49,6 @@ EWAPI extern const Efl_Event_Description _EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED;
  * @ingroup Efl_Ui_Tab_Page
  */
 #define EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED (&(_EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
