@@ -11,8 +11,27 @@ typedef Eo Elm_Code_Widget;
 #ifndef _ELM_CODE_WIDGET_EO_TYPES
 #define _ELM_CODE_WIDGET_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Type that controls when scrollbars should appear.
+ *
+ * See also @ref elm_interface_scrollable_policy_set.
+ *
+ * @ingroup Elm
+ */
+typedef enum
+{
+  ELM_CODE_WIDGET_SCROLLER_POLICY_AUTO = 0, /**< Show scrollbars as needed */
+  ELM_CODE_WIDGET_SCROLLER_POLICY_ON, /**< Always show scrollbars */
+  ELM_CODE_WIDGET_SCROLLER_POLICY_OFF, /**< Never show scrollbars */
+  ELM_CODE_WIDGET_SCROLLER_POLICY_LAST /**< Sentinel value to indicate last enum
+                                        * field during iteration */
+} Elm_Code_Widget_Scroller_Policy;
+#endif /* EFL_BETA_API_SUPPORT */
+
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elementary code widget
  *
  * @ingroup Elm_Code_Widget
@@ -31,7 +50,7 @@ EWAPI const Efl_Class *elm_code_widget_class_get(void);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_code_set(Eo *obj, Elm_Code *code);
+EOAPI void efl_ui_code_widget_code_set(Eo *obj, Elm_Code *code);
 
 /**
  * @brief Get the underlying code object we are rendering
@@ -42,7 +61,7 @@ EOAPI void elm_obj_code_widget_code_set(Eo *obj, Elm_Code *code);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Elm_Code *elm_obj_code_widget_code_get(const Eo *obj);
+EOAPI Elm_Code *efl_ui_code_widget_code_get(const Eo *obj);
 
 /**
  * @brief Set the font that this widget uses, the font should be a monospaced
@@ -54,7 +73,7 @@ EOAPI Elm_Code *elm_obj_code_widget_code_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_font_set(Eo *obj, const char *name, int size);
+EOAPI void efl_ui_code_widget_font_set(Eo *obj, const char *name, int size);
 
 /**
  * @brief Get the font currently in use. The font name is a copy ad should be
@@ -66,7 +85,7 @@ EOAPI void elm_obj_code_widget_font_set(Eo *obj, const char *name, int size);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_font_get(const Eo *obj, const char **name, int *size);
+EOAPI void efl_ui_code_widget_font_get(const Eo *obj, const char **name, int *size);
 
 /**
  * @brief Get the number of columns in the widget currently. This will be the
@@ -79,7 +98,7 @@ EOAPI void elm_obj_code_widget_font_get(const Eo *obj, const char **name, int *s
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_columns_get(const Eo *obj);
+EOAPI unsigned int efl_ui_code_widget_columns_get(const Eo *obj);
 
 /**
  * @brief Set how this widget's scroller should respond to new lines being
@@ -98,7 +117,7 @@ EOAPI unsigned int elm_obj_code_widget_columns_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_gravity_set(Eo *obj, double x, double y);
+EOAPI void efl_ui_code_widget_gravity_set(Eo *obj, double x, double y);
 
 /**
  * @brief Get the current x and y gravity of the widget's scroller
@@ -111,7 +130,7 @@ EOAPI void elm_obj_code_widget_gravity_set(Eo *obj, double x, double y);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_gravity_get(const Eo *obj, double *x, double *y);
+EOAPI void efl_ui_code_widget_gravity_get(const Eo *obj, double *x, double *y);
 
 /**
  * @brief Set the policy for scrollbar visibility.
@@ -122,7 +141,7 @@ EOAPI void elm_obj_code_widget_gravity_get(const Eo *obj, double *x, double *y);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_policy_set(Eo *obj, Elm_Scroller_Policy policy_h, Elm_Scroller_Policy policy_v);
+EOAPI void efl_ui_code_widget_policy_set(Eo *obj, Elm_Code_Widget_Scroller_Policy policy_h, Elm_Code_Widget_Scroller_Policy policy_v);
 
 /**
  * @brief Get the widget's policy for scrollbar visibility.
@@ -133,7 +152,7 @@ EOAPI void elm_obj_code_widget_policy_set(Eo *obj, Elm_Scroller_Policy policy_h,
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_policy_get(const Eo *obj, Elm_Scroller_Policy *policy_h, Elm_Scroller_Policy *policy_v);
+EOAPI void efl_ui_code_widget_policy_get(const Eo *obj, Elm_Code_Widget_Scroller_Policy *policy_h, Elm_Code_Widget_Scroller_Policy *policy_v);
 
 /**
  * @brief Set the width of a tab stop, used purely for visual layout of tab
@@ -146,7 +165,7 @@ EOAPI void elm_obj_code_widget_policy_get(const Eo *obj, Elm_Scroller_Policy *po
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_tabstop_set(Eo *obj, unsigned int tabstop);
+EOAPI void efl_ui_code_widget_tabstop_set(Eo *obj, unsigned int tabstop);
 
 /**
  * @brief Get the current width of a tab stop. This is used to determine where
@@ -158,7 +177,7 @@ EOAPI void elm_obj_code_widget_tabstop_set(Eo *obj, unsigned int tabstop);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_tabstop_get(const Eo *obj);
+EOAPI unsigned int efl_ui_code_widget_tabstop_get(const Eo *obj);
 
 /**
  * @brief Set whether this widget allows editing
@@ -173,7 +192,7 @@ EOAPI unsigned int elm_obj_code_widget_tabstop_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_editable_set(Eo *obj, Eina_Bool editable);
+EOAPI void efl_ui_code_widget_editable_set(Eo *obj, Eina_Bool editable);
 
 /**
  * @brief Get the current editable state of this widget
@@ -188,7 +207,7 @@ EOAPI void elm_obj_code_widget_editable_set(Eo *obj, Eina_Bool editable);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_editable_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_editable_get(const Eo *obj);
 
 /**
  * @brief Set whether line numbers should be displayed in the left gutter.
@@ -202,7 +221,7 @@ EOAPI Eina_Bool elm_obj_code_widget_editable_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_line_numbers_set(Eo *obj, Eina_Bool line_numbers);
+EOAPI void efl_ui_code_widget_line_numbers_set(Eo *obj, Eina_Bool line_numbers);
 
 /**
  * @brief Get the status of line number display for this widget.
@@ -213,7 +232,7 @@ EOAPI void elm_obj_code_widget_line_numbers_set(Eo *obj, Eina_Bool line_numbers)
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_line_numbers_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_line_numbers_get(const Eo *obj);
 
 /**
  * @brief Set where the line width market should be shown.
@@ -226,7 +245,7 @@ EOAPI Eina_Bool elm_obj_code_widget_line_numbers_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_line_width_marker_set(Eo *obj, unsigned int line_width_marker);
+EOAPI void efl_ui_code_widget_line_width_marker_set(Eo *obj, unsigned int line_width_marker);
 
 /**
  * @brief Get the position of the line width marker, any positive return
@@ -238,7 +257,7 @@ EOAPI void elm_obj_code_widget_line_width_marker_set(Eo *obj, unsigned int line_
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_line_width_marker_get(const Eo *obj);
+EOAPI unsigned int efl_ui_code_widget_line_width_marker_get(const Eo *obj);
 
 /**
  * @brief Set whether white space should be shown.
@@ -248,7 +267,7 @@ EOAPI unsigned int elm_obj_code_widget_line_width_marker_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_show_whitespace_set(Eo *obj, Eina_Bool show_whitespace);
+EOAPI void efl_ui_code_widget_show_whitespace_set(Eo *obj, Eina_Bool show_whitespace);
 
 /**
  * @brief Get whether or not white space will be visible.
@@ -259,7 +278,7 @@ EOAPI void elm_obj_code_widget_show_whitespace_set(Eo *obj, Eina_Bool show_white
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_show_whitespace_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_show_whitespace_get(const Eo *obj);
 
 /**
  * @brief Set an alpha color value for this widget (0 - 255) default is fully
@@ -270,7 +289,7 @@ EOAPI Eina_Bool elm_obj_code_widget_show_whitespace_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_alpha_set(Eo *obj, int alpha);
+EOAPI void efl_ui_code_widget_alpha_set(Eo *obj, int alpha);
 
 /**
  * @brief Set an alpha color value for this widget (0 - 255) default is fully
@@ -282,7 +301,7 @@ EOAPI void elm_obj_code_widget_alpha_set(Eo *obj, int alpha);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI int elm_obj_code_widget_alpha_get(const Eo *obj);
+EOAPI int efl_ui_code_widget_alpha_get(const Eo *obj);
 
 /**
  * @brief Set whether syntax highlighting should be use for this widget.
@@ -292,7 +311,7 @@ EOAPI int elm_obj_code_widget_alpha_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_syntax_enabled_set(Eo *obj, Eina_Bool syntax_enabled);
+EOAPI void efl_ui_code_widget_syntax_enabled_set(Eo *obj, Eina_Bool syntax_enabled);
 
 /**
  * @brief Get this widget's enabled state for syntax highlighting.
@@ -303,7 +322,7 @@ EOAPI void elm_obj_code_widget_syntax_enabled_set(Eo *obj, Eina_Bool syntax_enab
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_syntax_enabled_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_syntax_enabled_get(const Eo *obj);
 
 /**
  * @brief Set whether space characters should be inserted instead of tabs.
@@ -314,7 +333,7 @@ EOAPI Eina_Bool elm_obj_code_widget_syntax_enabled_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_tab_inserts_spaces_set(Eo *obj, Eina_Bool tab_inserts_spaces);
+EOAPI void efl_ui_code_widget_tab_inserts_spaces_set(Eo *obj, Eina_Bool tab_inserts_spaces);
 
 /**
  * @brief Get whether or not space characters will be inserted instead of tabs.
@@ -326,7 +345,7 @@ EOAPI void elm_obj_code_widget_tab_inserts_spaces_set(Eo *obj, Eina_Bool tab_ins
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_tab_inserts_spaces_get(const Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_tab_inserts_spaces_get(const Eo *obj);
 
 /**
  * @brief Set the current location of the text cursor.
@@ -337,7 +356,7 @@ EOAPI Eina_Bool elm_obj_code_widget_tab_inserts_spaces_get(const Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_cursor_position_set(Eo *obj, unsigned int row, unsigned int col);
+EOAPI void efl_ui_code_widget_cursor_position_set(Eo *obj, unsigned int row, unsigned int col);
 
 /**
  * @brief Get the current x and y position of the widget's cursor.
@@ -349,13 +368,13 @@ EOAPI void elm_obj_code_widget_cursor_position_set(Eo *obj, unsigned int row, un
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_cursor_position_get(const Eo *obj, unsigned int *row, unsigned int *col);
+EOAPI void efl_ui_code_widget_cursor_position_get(const Eo *obj, unsigned int *row, unsigned int *col);
 
 /** Update and refresh theme for widget.
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_theme_refresh(Eo *obj);
+EOAPI void efl_ui_code_widget_theme_refresh(Eo *obj);
 
 /**
  * @brief Refresh code line in widget
@@ -365,7 +384,7 @@ EOAPI void elm_obj_code_widget_theme_refresh(Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_line_refresh(Eo *obj, Elm_Code_Line *line);
+EOAPI void efl_ui_code_widget_line_refresh(Eo *obj, Elm_Code_Line *line);
 
 /**
  * @brief Check if the code line is currently visible
@@ -378,7 +397,7 @@ EOAPI void elm_obj_code_widget_line_refresh(Eo *obj, Elm_Code_Line *line);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_line_visible_get(Eo *obj, Elm_Code_Line *line);
+EOAPI Eina_Bool efl_ui_code_widget_line_visible_get(Eo *obj, Elm_Code_Line *line);
 
 /**
  * @brief Get the number of code lines currently visible in the widget
@@ -389,7 +408,7 @@ EOAPI Eina_Bool elm_obj_code_widget_line_visible_get(Eo *obj, Elm_Code_Line *lin
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_lines_visible_get(Eo *obj);
+EOAPI unsigned int efl_ui_code_widget_lines_visible_get(Eo *obj);
 
 /**
  * @brief Get the row, col position for a given coordinate on the widget.
@@ -404,7 +423,7 @@ EOAPI unsigned int elm_obj_code_widget_lines_visible_get(Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_position_at_coordinates_get(Eo *obj, int x, int y, unsigned int *row, int *col);
+EOAPI Eina_Bool efl_ui_code_widget_position_at_coordinates_get(Eo *obj, int x, int y, unsigned int *row, int *col);
 
 /**
  * @brief Get the geometry for the cell at the specified position.
@@ -421,7 +440,7 @@ EOAPI Eina_Bool elm_obj_code_widget_position_at_coordinates_get(Eo *obj, int x,
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_geometry_for_position_get(Eo *obj, unsigned int row, int col, int *x, int *y, int *w, int *h);
+EOAPI Eina_Bool efl_ui_code_widget_geometry_for_position_get(Eo *obj, unsigned int row, int col, int *x, int *y, int *w, int *h);
 
 /**
  * @brief Get the column width of the gutter
@@ -432,7 +451,7 @@ EOAPI Eina_Bool elm_obj_code_widget_geometry_for_position_get(Eo *obj, unsigned
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI int elm_obj_code_widget_text_left_gutter_width_get(Eo *obj);
+EOAPI int efl_ui_code_widget_text_left_gutter_width_get(Eo *obj);
 
 /**
  * @brief Get text between given positions
@@ -447,7 +466,7 @@ EOAPI int elm_obj_code_widget_text_left_gutter_width_get(Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI char *elm_obj_code_widget_text_between_positions_get(Eo *obj, unsigned int start_line, unsigned int start_col, unsigned int end_line, unsigned int end_col);
+EOAPI char *efl_ui_code_widget_text_between_positions_get(Eo *obj, unsigned int start_line, unsigned int start_col, unsigned int end_line, unsigned int end_col);
 
 /**
  * @brief Insert the provided text at the cursor position. This will add the
@@ -458,7 +477,7 @@ EOAPI char *elm_obj_code_widget_text_between_positions_get(Eo *obj, unsigned int
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_text_at_cursor_insert(Eo *obj, const char *text);
+EOAPI void efl_ui_code_widget_text_at_cursor_insert(Eo *obj, const char *text);
 
 /**
  * @brief Get text column width at given position
@@ -471,7 +490,7 @@ EOAPI void elm_obj_code_widget_text_at_cursor_insert(Eo *obj, const char *text);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_line_text_column_width_to_position(Eo *obj, Elm_Code_Line *line, unsigned int position);
+EOAPI unsigned int efl_ui_code_widget_line_text_column_width_to_position(Eo *obj, Elm_Code_Line *line, unsigned int position);
 
 /**
  * @brief Get text column width for code line
@@ -483,7 +502,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_column_width_to_position(Eo *ob
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_line_text_column_width_get(Eo *obj, Elm_Code_Line *line);
+EOAPI unsigned int efl_ui_code_widget_line_text_column_width_get(Eo *obj, Elm_Code_Line *line);
 
 /**
  * @brief Get position from column
@@ -496,7 +515,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_column_width_get(Eo *obj, Elm_C
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_line_text_position_for_column_get(Eo *obj, Elm_Code_Line *line, unsigned int column);
+EOAPI unsigned int efl_ui_code_widget_line_text_position_for_column_get(Eo *obj, Elm_Code_Line *line, unsigned int column);
 
 /**
  * @brief Get tabwidth for column
@@ -508,7 +527,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_position_for_column_get(Eo *obj
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI unsigned int elm_obj_code_widget_text_tabwidth_at_column_get(Eo *obj, unsigned int column);
+EOAPI unsigned int efl_ui_code_widget_text_tabwidth_at_column_get(Eo *obj, unsigned int column);
 
 /**
  * @brief Toggle the display of the line status widget
@@ -518,13 +537,13 @@ EOAPI unsigned int elm_obj_code_widget_text_tabwidth_at_column_get(Eo *obj, unsi
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_line_status_toggle(Eo *obj, Elm_Code_Line *line);
+EOAPI void efl_ui_code_widget_line_status_toggle(Eo *obj, Elm_Code_Line *line);
 
 /** Undo last action
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_undo(Eo *obj);
+EOAPI void efl_ui_code_widget_undo(Eo *obj);
 
 /**
  * @brief Determine if there are any available undo operations
@@ -535,13 +554,13 @@ EOAPI void elm_obj_code_widget_undo(Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_can_undo_get(Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_can_undo_get(Eo *obj);
 
 /** Redo last action
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI void elm_obj_code_widget_redo(Eo *obj);
+EOAPI void efl_ui_code_widget_redo(Eo *obj);
 
 /**
  * @brief Determine if there are any available redo operations
@@ -552,95 +571,96 @@ EOAPI void elm_obj_code_widget_redo(Eo *obj);
  *
  * @ingroup Elm_Code_Widget
  */
-EOAPI Eina_Bool elm_obj_code_widget_can_redo_get(Eo *obj);
+EOAPI Eina_Bool efl_ui_code_widget_can_redo_get(Eo *obj);
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_LINE_CLICKED;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_LINE_CLICKED;
 
 /** Called when text line was clicked
  * @return Elm_Code_Line
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_LINE_CLICKED (&(_ELM_OBJ_CODE_WIDGET_EVENT_LINE_CLICKED))
+#define EFL_UI_CODE_WIDGET_EVENT_LINE_CLICKED (&(_EFL_UI_CODE_WIDGET_EVENT_LINE_CLICKED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED;
 
 /** Called when gutter was clicked
  * @return Elm_Code_Line
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED (&(_ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED))
+#define EFL_UI_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED (&(_EFL_UI_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CHANGED_USER;
 
 /** Called when object changed due to user interaction
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER (&(_ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER))
+#define EFL_UI_CODE_WIDGET_EVENT_CHANGED_USER (&(_EFL_UI_CODE_WIDGET_EVENT_CHANGED_USER))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CURSOR_CHANGED;
 
 /** Called when cursor changed
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED (&(_ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED))
+#define EFL_UI_CODE_WIDGET_EVENT_CURSOR_CHANGED (&(_EFL_UI_CODE_WIDGET_EVENT_CURSOR_CHANGED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_START;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_START;
 
 /** Called when a selection is started
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_START (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_START))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_START (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_START))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CHANGED;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CHANGED;
 
 /** Called when selection changed
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CHANGED (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CHANGED))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CHANGED (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CHANGED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CLEARED;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CLEARED;
 
 /** Called when selection was cleared
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CLEARED (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CLEARED))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CLEARED (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CLEARED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CUT;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CUT;
 
 /** Called when a cut action is performed
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CUT (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CUT))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CUT (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_CUT))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_COPY;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_COPY;
 
 /** Called when a copy action is performed
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_COPY (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_COPY))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_COPY (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_COPY))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_PASTE;
+EWAPI extern const Efl_Event_Description _EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_PASTE;
 
 /** Called when a paste action is performed
  * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
-#define ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_PASTE (&(_ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_PASTE))
+#define EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_PASTE (&(_EFL_UI_CODE_WIDGET_EVENT_CODE_SELECTION_PASTE))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
