@@ -14,7 +14,7 @@ typedef Eo Elm_Interface_Scrollable;
 /**
  * @brief Type that controls when scrollbars should appear.
  *
- * See also @ref Elm.Interface_Scrollable.policy.set.
+ * See also @ref elm_interface_scrollable_policy_set.
  *
  * @ingroup Elm_Scroller
  */
@@ -30,7 +30,7 @@ typedef enum
 /**
  * @brief Type that controls how the content is scrolled.
  *
- * See also @ref Elm.Interface_Scrollable.single_direction.set.
+ * See also @ref elm_interface_scrollable_single_direction_set.
  *
  * @ingroup Elm_Scroller
  */
@@ -44,95 +44,7 @@ typedef enum
                                       * field during iteration */
 } Elm_Scroller_Single_Direction;
 
-/** Type that blocks the scroll movement in one or more direction.
- *
- * @since 1.8
- *
- * @ingroup Elm_Scroller
- */
-typedef enum
-{
-  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1 /* 1 >> 0 */, /**< Do not block movements
-                                                    */
-  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2 /* 1 >> 1 */, /**< Block vertical
-                                                          * movements */
-  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /* 1 >> 2 */ /**< Block horizontal
-                                                           * movements */
-} Elm_Scroller_Movement_Block;
-
 
 #endif
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #endif
