@@ -1,5 +1,20 @@
 #include "elm_interface_scrollable.eo.legacy.h"
-#include "elm_scroller.eo.legacy.h"
+#include "elm_scroller_eo.legacy.h"
+
+/**
+ * Type that blocks the scroll movement in one or more direction.
+ *
+ * @since 1.8
+ *
+ * @ingroup Elm_Scroller
+ */
+typedef enum
+{
+  ELM_SCROLLER_MOVEMENT_NO_BLOCK = 1, /**< Do not block movements */
+  ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL = 2, /**< Block vertical movements */
+  ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL = 4 /**< Block horizontal movements */
+} Elm_Scroller_Movement_Block;
+
 /**
  * @brief Add a new scroller to the parent
  *
@@ -401,7 +416,7 @@ EAPI void                          elm_scroller_region_bring_in(Evas_Object *obj
  * The scroller will adjust the view to glue itself as follows.
  *
  *  x=0.0, for staying where it is relative to the left edge of the content
- *  x=1.0, for staying where it is relative to the rigth edge of the content
+ *  x=1.0, for staying where it is relative to the right edge of the content
  *  y=0.0, for staying where it is relative to the top edge of the content
  *  y=1.0, for staying where it is relative to the bottom edge of the content
  *
@@ -559,3 +574,28 @@ EAPI void                          elm_scroller_wheel_disabled_set(Evas_Object *
  * @ingroup Elm_Scroller
  */
 EAPI Eina_Bool                     elm_scroller_wheel_disabled_get(const Evas_Object *obj);
+
+/**
+ * @brief Set event propagation on a scroller
+ *
+ * This enables or disables event propagation from the scroller content to the
+ * scroller and its parent. By default event propagation is enabled.
+ *
+ * @param[in] obj The scroller object
+ * @param[in] propagation The propagation state
+ *
+ * @ingroup Elm_Scroller
+ */
+EAPI void elm_scroller_propagate_events_set(Evas_Object *obj, Eina_Bool propagation);
+
+/**
+ * @brief Get event propagation for a scroller
+ *
+ * This gets the event propagation for a scroller.
+ *
+ * @param[in] obj The scroller object
+ * @return The propagation state
+ *
+ * @ingroup Elm_Scroller
+ */
+EAPI Eina_Bool elm_scroller_propagate_events_get(const Evas_Object *obj);
