@@ -316,6 +316,9 @@ typedef enum
 
    EOLIAN_TYPE_BUILTIN_BOOL,
 
+   EOLIAN_TYPE_BUILTIN_SLICE,
+   EOLIAN_TYPE_BUILTIN_RW_SLICE,
+
    EOLIAN_TYPE_BUILTIN_VOID,
 
    EOLIAN_TYPE_BUILTIN_ACCESSOR,
@@ -324,8 +327,6 @@ typedef enum
    EOLIAN_TYPE_BUILTIN_ITERATOR,
    EOLIAN_TYPE_BUILTIN_HASH,
    EOLIAN_TYPE_BUILTIN_LIST,
-   EOLIAN_TYPE_BUILTIN_INARRAY,
-   EOLIAN_TYPE_BUILTIN_INLIST,
 
    EOLIAN_TYPE_BUILTIN_ANY_VALUE,
    EOLIAN_TYPE_BUILTIN_ANY_VALUE_PTR,
@@ -333,6 +334,7 @@ typedef enum
    EOLIAN_TYPE_BUILTIN_MSTRING,
    EOLIAN_TYPE_BUILTIN_STRING,
    EOLIAN_TYPE_BUILTIN_STRINGSHARE,
+   EOLIAN_TYPE_BUILTIN_STRBUF,
 
    EOLIAN_TYPE_BUILTIN_VOID_PTR,
    EOLIAN_TYPE_BUILTIN_FREE_CB
@@ -700,6 +702,19 @@ EAPI const char *eolian_object_short_name_get(const Eolian_Object *obj);
  */
 EAPI Eina_Iterator *eolian_object_namespaces_get(const Eolian_Object *obj);
 
+/*
+ * @brief Get whether an object is beta.
+ *
+ * This applies to toplevel objects (classes, types) as well as some
+ * others such as functions and events.
+ *
+ * @param[in] obj The object.
+ * @return EINA_TRUE and EINA_FALSE respectively
+ *
+ * @ingroup Eolian
+ */
+EAPI Eina_Bool eolian_object_is_beta(const Eolian_Object *obj);
+
 /*
  * @brief Scan the given directory for .eo and .eot files.
  *
@@ -909,10 +924,26 @@ EAPI Eina_Iterator *eolian_unit_children_get(const Eolian_Unit *unit);
  *
  * @param[in] unit The unit.
  *
+ * @see eolian_unit_file_path_get
+ *
  * @ingroup Eolian
  */
 EAPI const char *eolian_unit_file_get(const Eolian_Unit *unit);
 
+/*
+ * @brief Get the full file path a unit is associated with.
+ *
+ * This will be `NULL` if not associated with a file (like the master unit
+ * within `Eolian_State`).
+ *
+ * @param[in] unit The unit.
+ *
+ * @see eolian_unit_file_get
+ *
+ * @ingroup Eolian
+ */
+EAPI const char *eolian_unit_file_path_get(const Eolian_Unit *unit);
+
 /*
  * @brief Get an object in a unit by name.
  *
@@ -1389,16 +1420,6 @@ EAPI Eolian_Class_Type eolian_class_type_get(const Eolian_Class *klass);
  */
 EAPI const Eolian_Documentation *eolian_class_documentation_get(const Eolian_Class *klass);
 
-/*
- * @brief Returns the legacy prefix of a class
- *
- * @param[in] klass the class
- * @return the legacy prefix
- *
- * @ingroup Eolian
- */
-EAPI Eina_Stringshare *eolian_class_legacy_prefix_get(const Eolian_Class *klass);
-
 /*
  * @brief Returns the eo prefix of a class
  *
@@ -1430,14 +1451,49 @@ EAPI Eina_Stringshare* eolian_class_event_prefix_get(const Eolian_Class *klass);
 EAPI Eina_Stringshare *eolian_class_data_type_get(const Eolian_Class *klass);
 
 /*
- * @brief Returns an iterator to the inherited classes.
+ * @brief Get the parent class of a class
+ *
+ * This is the class the class inherits from. It only applies to classes,
+ * as Eo follows a single-inheritance model with interfaces. This will be
+ * NULL for any non-class (i.e. interface or mixin).
+ *
+ * @param[in] klass the class
+ * @return the parent
+ *
+ * @see eolian_class_extensions_get
+ *
+ * @ingroup Eolian
+ */
+EAPI const Eolian_Class *eolian_class_parent_get(const Eolian_Class *klass);
+
+/*
+ * @brief Returns an iterator to the required classes of this mixin
+ *
+ * For none mixins this will return an empty iterator, for mixins this retuns a iterator that
+ * carries all the classes that are required by this passed mixin.
  *
  * @param[in] klass the class
  * @return the iterator
  *
  * @ingroup Eolian
  */
-EAPI Eina_Iterator *eolian_class_inherits_get(const Eolian_Class *klass);
+EAPI Eina_Iterator *eolian_class_requires_get(const Eolian_Class *klass);
+
+/*
+ * @brief Returns an iterator to the class extensions
+ *
+ * For regular classes, extensions are interfaces/mixins for the class, i.e.
+ * everything past the parent class. For interfaces/mixins, this is everything
+ * in the inherits list.
+ *
+ * @param[in] klass the class
+ * @return the iterator
+ *
+ * @see eolian_class_parent_get
+ *
+ * @ingroup Eolian
+ */
+EAPI Eina_Iterator *eolian_class_extensions_get(const Eolian_Class *klass);
 
 /*
  * @brief Returns an iterator to functions of a class.
@@ -1493,22 +1549,20 @@ eolian_function_name_get(const Eolian_Function *fid)
  *
  * @param[in] function_id Id of the function
  * @param[in] ftype The type of function to get the name for
- * @param[in] use_legacy If true, legacy prefix or name will be used when available
  * @return the function name
  *
  * It's here because the C API names are deduplicated (prefix of function and
  * suffix of prefix merge if applicable) and this helps generators not write
  * the same code over and over.
  *
- * If legacy name is supplied for the given type and use_legacy is set, it
- * will be used. Also, if the given type is PROP_GET or PROPERTY, a "_get"
- * suffix will be applied when not using legacy name, and "_set" for PROP_SET.
+ * If the given type is PROP_GET or PROPERTY, a "_get" suffix will be applied,
+ * and "_set" for PROP_SET.
  *
  * Also, you're responsible for deleting the stringshare.
  *
  * @ingroup Eolian
  */
-EAPI Eina_Stringshare *eolian_function_full_c_name_get(const Eolian_Function *function_id, Eolian_Function_Type ftype, Eina_Bool use_legacy);
+EAPI Eina_Stringshare *eolian_function_full_c_name_get(const Eolian_Function *function_id, Eolian_Function_Type ftype);
 
 /*
  * @brief Get a function in a class by its name and type
@@ -1526,19 +1580,6 @@ EAPI Eina_Stringshare *eolian_function_full_c_name_get(const Eolian_Function *fu
  */
 EAPI const Eolian_Function *eolian_class_function_by_name_get(const Eolian_Class *klass, const char *func_name, Eolian_Function_Type f_type);
 
-/*
- * @brief Returns a legacy name for a function.
- *
- * @param[in] function_id Id of the function
- * @param[in] f_type The function type, for property get/set distinction.
- * @return the legacy name or NULL.
- *
- * Acceptable input types are METHOD, PROP_GET and PROP_SET.
- *
- * @ingroup Eolian
- */
-EAPI Eina_Stringshare *eolian_function_legacy_get(const Eolian_Function *function_id, Eolian_Function_Type f_type);
-
 /*
  * @brief Returns the implement for a function.
  *
@@ -1549,19 +1590,6 @@ EAPI Eina_Stringshare *eolian_function_legacy_get(const Eolian_Function *functio
  */
 EAPI const Eolian_Implement *eolian_function_implement_get(const Eolian_Function *function_id);
 
-/*
- * @brief Indicates if a function is legacy only.
- *
- * @param[in] function_id Id of the function
- * @param[in] f_type The function type, for property get/set distinction.
- * @return EINA_TRUE if legacy only, EINA_FALSE otherwise.
- *
- * Acceptable input types are METHOD, PROP_GET and PROP_SET.
- *
- * @ingroup Eolian
- */
-EAPI Eina_Bool eolian_function_is_legacy_only(const Eolian_Function *function_id, Eolian_Function_Type ftype);
-
 /*
  * @brief Get whether a function is a class method/property.
  *
@@ -1575,12 +1603,15 @@ EAPI Eina_Bool eolian_function_is_class(const Eolian_Function *function_id);
 /*
  * @brief Get whether a function is beta.
  *
- * @param[in] function_id Id of the function
- * @return EINA_TRUE and EINA_FALSE respectively
+ * @see eolian_object_is_beta
  *
  * @ingroup Eolian
  */
-EAPI Eina_Bool eolian_function_is_beta(const Eolian_Function *function_id);
+static inline Eina_Bool
+eolian_function_is_beta(const Eolian_Function *function_id)
+{
+   return eolian_object_is_beta(EOLIAN_OBJECT(function_id));
+}
 
 /*
  * @brief Indicates if a function is a constructing function of a given class.
@@ -1824,13 +1855,35 @@ eolian_implement_name_get(const Eolian_Implement *impl)
 /*
  * @brief Get the class of an overriding function (implement).
  *
+ * This is always the class specified in the implement name, i.e. if a class
+ * B overrides a method from a class A, the returned class will be A. There
+ * is another API to get the overriding class.
+ *
  * @param[in] impl the handle of the implement
  * @return the class handle or NULL.
  *
+ * @see eolian_implement_implementing_class_get
+ *
  * @ingroup Eolian
  */
 EAPI const Eolian_Class *eolian_implement_class_get(const Eolian_Implement *impl);
 
+/*
+ * @brief Get the implementing class of an overriding function (implement).
+ *
+ * This is always the class that is implementing the function, override or
+ * not. That is, if class B overrides a method from class A, this will return
+ * the B class. There is another API to get the original class.
+ *
+ * @param[in] impl the handle of the implement
+ * @return the class handle or NULL.
+ *
+ * @see eolian_implement_class_get
+ *
+ * @ingroup Eolian
+ */
+EAPI const Eolian_Class *eolian_implement_implementing_class_get(const Eolian_Implement *impl);
+
 /*
  * @brief Get the function of an implement.
  *
@@ -1972,6 +2025,16 @@ EAPI const Eolian_Function *eolian_constructor_function_get(const Eolian_Constru
  */
 EAPI Eina_Bool eolian_constructor_is_optional(const Eolian_Constructor *ctor);
 
+/*
+ * @brief Checks if a constructor is tagged as a constructor parameter.
+ *
+ * @param[in] ctor the handle of the constructor
+ * @return EINA_TRUE if a constructor parameter, EINA_FALSE if not (or if input is NULL).
+ *
+ * @ingroup Eolian
+ */
+EAPI Eina_Bool eolian_constructor_is_ctor_param(const Eolian_Constructor *ctor);
+
 /*
  * @brief Get an iterator to the constructing functions defined in a class.
  *
@@ -2015,6 +2078,16 @@ eolian_event_name_get(const Eolian_Event *event)
  */
 EAPI const Eolian_Type *eolian_event_type_get(const Eolian_Event *event);
 
+/*
+ * @brief Get the class of an event.
+ *
+ * @param[in] event the event handle
+ * @return the class or NULL
+ *
+ * @ingroup Eolian
+ */
+EAPI const Eolian_Class *eolian_event_class_get(const Eolian_Event *event);
+
 /*
  * @brief Get the documentation of an event.
  *
@@ -2038,12 +2111,15 @@ EAPI Eolian_Object_Scope eolian_event_scope_get(const Eolian_Event *event);
 /*
  * @brief Get whether an event is beta.
  *
- * @param[in] event the event handle
- * @return EINA_TRUE and EINA_FALSE respectively
+ * @see eolian_object_is_beta
  *
  * @ingroup Eolian
  */
-EAPI Eina_Bool eolian_event_is_beta(const Eolian_Event *event);
+static inline Eina_Bool
+eolian_event_is_beta(const Eolian_Event *event)
+{
+   return eolian_object_is_beta(EOLIAN_OBJECT(event));
+}
 
 /*
  * @brief Get whether an event is hot (unfreezable).
@@ -2205,6 +2281,19 @@ EAPI Eina_Stringshare *eolian_class_c_name_get(const Eolian_Class *klass);
  */
 EAPI Eina_Stringshare *eolian_class_c_data_type_get(const Eolian_Class *klass);
 
+/*
+ * @brief Get whether a class is beta.
+ *
+ * @see eolian_object_is_beta
+ *
+ * @ingroup Eolian
+ */
+static inline Eina_Bool
+eolian_class_is_beta(const Eolian_Class *klass)
+{
+   return eolian_object_is_beta(EOLIAN_OBJECT(klass));
+}
+
 /*
  * @brief Get the type of a type declaration.
  *
@@ -2400,6 +2489,19 @@ EAPI const Eolian_Type *eolian_typedecl_aliased_base_get(const Eolian_Typedecl *
  */
 EAPI Eina_Bool eolian_typedecl_is_extern(const Eolian_Typedecl *tp);
 
+/*
+ * @brief Get whether a typedecl is beta.
+ *
+ * @see eolian_object_is_beta
+ *
+ * @ingroup Eolian
+ */
+static inline Eina_Bool
+eolian_typedecl_is_beta(const Eolian_Typedecl *tp)
+{
+   return eolian_object_is_beta(EOLIAN_OBJECT(tp));
+}
+
 /*
  * @brief Get the full C type name of the given type.
  *
@@ -2464,7 +2566,7 @@ eolian_typedecl_namespaces_get(const Eolian_Typedecl *tp)
 EAPI Eina_Stringshare *eolian_typedecl_free_func_get(const Eolian_Typedecl *tp);
 
 /*
- * @breif Get the function object for this function pointer type.
+ * @brief Get the function object for this function pointer type.
  *
  * @param[in] tp the type.
  * @return the function or NULL;
@@ -2901,6 +3003,19 @@ eolian_variable_namespaces_get(const Eolian_Variable *tp)
  */
 EAPI Eina_Bool eolian_variable_is_extern(const Eolian_Variable *var);
 
+/*
+ * @brief Get whether a variable is beta.
+ *
+ * @see eolian_object_is_beta
+ *
+ * @ingroup Eolian
+ */
+static inline Eina_Bool
+eolian_variable_is_beta(const Eolian_Variable *var)
+{
+   return eolian_object_is_beta(EOLIAN_OBJECT(var));
+}
+
 /*
  * @brief Get the summary of the documentation.
  *
