@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Animation_Group_Sequential;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Efl group sequential animation class
  *
  * @ingroup Efl_Canvas_Animation_Group_Sequential
@@ -20,5 +21,6 @@ typedef Eo Efl_Canvas_Animation_Group_Sequential;
 #define EFL_CANVAS_ANIMATION_GROUP_SEQUENTIAL_CLASS efl_canvas_animation_group_sequential_class_get()
 
 EWAPI const Efl_Class *efl_canvas_animation_group_sequential_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
