@@ -13,7 +13,9 @@ typedef Eo Efl_Input_State;
 
 
 #endif
-/** Efl input state interface
+/** Efl input state interface.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Input_State
  */
@@ -21,6 +23,7 @@ typedef Eo Efl_Input_State;
 
 EWAPI const Efl_Class *efl_input_state_interface_get(void);
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Indicates whether a key modifier is on, such as Ctrl, Shift, ...
  *
@@ -30,10 +33,14 @@ EWAPI const Efl_Class *efl_input_state_interface_get(void);
  *
  * @return @c true if the key modifier is pressed.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Input_State
  */
 EOAPI Eina_Bool efl_input_modifier_enabled_get(const Eo *obj, Efl_Input_Modifier mod, const Efl_Input_Device *seat);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Indicates whether a key lock is on, such as NumLock, CapsLock, ...
  *
@@ -43,8 +50,11 @@ EOAPI Eina_Bool efl_input_modifier_enabled_get(const Eo *obj, Efl_Input_Modifier
  *
  * @return @c true if the key lock is on.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Input_State
  */
 EOAPI Eina_Bool efl_input_lock_enabled_get(const Eo *obj, Efl_Input_Lock lock, const Efl_Input_Device *seat);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
